==> openshift-model-operatorhub-5.8.1-sources.jar: io/fabric8/openshift/api/model/operatorhub/v1alpha1/SubscriptionStatusFluent.java <==
package io.fabric8.openshift.api.model.operatorhub.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import io.fabric8.kubernetes.api.model.ObjectReference;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Integer;
import io.fabric8.kubernetes.api.model.ObjectReferenceFluent;
import io.fabric8.kubernetes.api.model.ObjectReferenceBuilder;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public interface SubscriptionStatusFluent<A extends io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionStatusFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public A addToCatalogHealth(java.lang.Integer index,io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionCatalogHealth item);
  public A setToCatalogHealth(java.lang.Integer index,io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionCatalogHealth item);
  public A addToCatalogHealth(io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionCatalogHealth... items);
  public A addAllToCatalogHealth(java.util.Collection<io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionCatalogHealth> items);
  public A removeFromCatalogHealth(io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionCatalogHealth... items);
  public A removeAllFromCatalogHealth(java.util.Collection<io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionCatalogHealth> items);
  public A removeMatchingFromCatalogHealth(java.util.function.Predicate<io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionCatalogHealthBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildCatalogHealth instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionCatalogHealth> getCatalogHealth();
  public java.util.List<io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionCatalogHealth> buildCatalogHealth();
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionCatalogHealth buildCatalogHealth(java.lang.Integer index);
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionCatalogHealth buildFirstCatalogHealth();
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionCatalogHealth buildLastCatalogHealth();
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionCatalogHealth buildMatchingCatalogHealth(java.util.function.Predicate<io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionCatalogHealthBuilder> predicate);
  public java.lang.Boolean hasMatchingCatalogHealth(java.util.function.Predicate<io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionCatalogHealthBuilder> predicate);
  public A withCatalogHealth(java.util.List<io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionCatalogHealth> catalogHealth);
  public A withCatalogHealth(io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionCatalogHealth... catalogHealth);
  public java.lang.Boolean hasCatalogHealth();
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionStatusFluent.CatalogHealthNested<A> addNewCatalogHealth();
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionStatusFluent.CatalogHealthNested<A> addNewCatalogHealthLike(io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionCatalogHealth item);
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionStatusFluent.CatalogHealthNested<A> setNewCatalogHealthLike(java.lang.Integer index,io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionCatalogHealth item);
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionStatusFluent.CatalogHealthNested<A> editCatalogHealth(java.lang.Integer index);
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionStatusFluent.CatalogHealthNested<A> editFirstCatalogHealth();
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionStatusFluent.CatalogHealthNested<A> editLastCatalogHealth();
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionStatusFluent.CatalogHealthNested<A> editMatchingCatalogHealth(java.util.function.Predicate<io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionCatalogHealthBuilder> predicate);
  public A addToConditions(java.lang.Integer index,io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionCondition item);
  public A setToConditions(java.lang.Integer index,io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionCondition item);
  public A addToConditions(io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionCondition... items);
  public A addAllToConditions(java.util.Collection<io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionCondition> items);
  public A removeFromConditions(io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionCondition... items);
  public A removeAllFromConditions(java.util.Collection<io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionCondition> items);
  public A removeMatchingFromConditions(java.util.function.Predicate<io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionConditionBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildConditions instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionCondition> getConditions();
  public java.util.List<io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionCondition> buildConditions();
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionCondition buildCondition(java.lang.Integer index);
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionCondition buildFirstCondition();
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionCondition buildLastCondition();
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionCondition buildMatchingCondition(java.util.function.Predicate<io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionConditionBuilder> predicate);
  public java.lang.Boolean hasMatchingCondition(java.util.function.Predicate<io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionConditionBuilder> predicate);
  public A withConditions(java.util.List<io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionCondition> conditions);
  public A withConditions(io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionCondition... conditions);
  public java.lang.Boolean hasConditions();
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionStatusFluent.ConditionsNested<A> addNewCondition();
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionStatusFluent.ConditionsNested<A> addNewConditionLike(io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionCondition item);
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionStatusFluent.ConditionsNested<A> setNewConditionLike(java.lang.Integer index,io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionCondition item);
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionStatusFluent.ConditionsNested<A> editCondition(java.lang.Integer index);
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionStatusFluent.ConditionsNested<A> editFirstCondition();
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionStatusFluent.ConditionsNested<A> editLastCondition();
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionStatusFluent.ConditionsNested<A> editMatchingCondition(java.util.function.Predicate<io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionConditionBuilder> predicate);
  public java.lang.String getCurrentCSV();
  public A withCurrentCSV(java.lang.String currentCSV);
  public java.lang.Boolean hasCurrentCSV();
  
  /**
   * Method is deprecated. use withCurrentCSV instead.
   */
  @java.lang.Deprecated
  public A withNewCurrentCSV(java.lang.String arg0);
  public java.lang.Integer getInstallPlanGeneration();
  public A withInstallPlanGeneration(java.lang.Integer installPlanGeneration);
  public java.lang.Boolean hasInstallPlanGeneration();
  
  /**
   * This method has been deprecated, please use method buildInstallPlanRef instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.ObjectReference getInstallPlanRef();
  public io.fabric8.kubernetes.api.model.ObjectReference buildInstallPlanRef();
  public A withInstallPlanRef(io.fabric8.kubernetes.api.model.ObjectReference installPlanRef);
  public java.lang.Boolean hasInstallPlanRef();
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionStatusFluent.InstallPlanRefNested<A> withNewInstallPlanRef();
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionStatusFluent.InstallPlanRefNested<A> withNewInstallPlanRefLike(io.fabric8.kubernetes.api.model.ObjectReference item);
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionStatusFluent.InstallPlanRefNested<A> editInstallPlanRef();
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionStatusFluent.InstallPlanRefNested<A> editOrNewInstallPlanRef();
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionStatusFluent.InstallPlanRefNested<A> editOrNewInstallPlanRefLike(io.fabric8.kubernetes.api.model.ObjectReference item);
  public java.lang.String getInstalledCSV();
  public A withInstalledCSV(java.lang.String installedCSV);
  public java.lang.Boolean hasInstalledCSV();
  
  /**
   * Method is deprecated. use withInstalledCSV instead.
   */
  @java.lang.Deprecated
  public A withNewInstalledCSV(java.lang.String arg0);
  
  /**
   * This method has been deprecated, please use method buildInstallplan instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.InstallPlanReference getInstallplan();
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.InstallPlanReference buildInstallplan();
  public A withInstallplan(io.fabric8.openshift.api.model.operatorhub.v1alpha1.InstallPlanReference installplan);
  public java.lang.Boolean hasInstallplan();
  public A withNewInstallplan(java.lang.String apiVersion,java.lang.String kind,java.lang.String name,java.lang.String uuid);
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionStatusFluent.InstallplanNested<A> withNewInstallplan();
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionStatusFluent.InstallplanNested<A> withNewInstallplanLike(io.fabric8.openshift.api.model.operatorhub.v1alpha1.InstallPlanReference item);
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionStatusFluent.InstallplanNested<A> editInstallplan();
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionStatusFluent.InstallplanNested<A> editOrNewInstallplan();
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionStatusFluent.InstallplanNested<A> editOrNewInstallplanLike(io.fabric8.openshift.api.model.operatorhub.v1alpha1.InstallPlanReference item);
  public java.lang.String getLastUpdated();
  public A withLastUpdated(java.lang.String lastUpdated);
  public java.lang.Boolean hasLastUpdated();
  
  /**
   * Method is deprecated. use withLastUpdated instead.
   */
  @java.lang.Deprecated
  public A withNewLastUpdated(java.lang.String arg0);
  public java.lang.String getReason();
  public A withReason(java.lang.String reason);
  public java.lang.Boolean hasReason();
  
  /**
   * Method is deprecated. use withReason instead.
   */
  @java.lang.Deprecated
  public A withNewReason(java.lang.String arg0);
  public java.lang.String getState();
  public A withState(java.lang.String state);
  public java.lang.Boolean hasState();
  
  /**
   * Method is deprecated. use withState instead.
   */
  @java.lang.Deprecated
  public A withNewState(java.lang.String arg0);
  public interface CatalogHealthNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionCatalogHealthFluent<io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionStatusFluent.CatalogHealthNested<N>>{
    public N and();
    public N endCatalogHealth();
    
  }
  public interface ConditionsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionConditionFluent<io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionStatusFluent.ConditionsNested<N>>{
    public N and();
    public N endCondition();
    
  }
  public interface InstallPlanRefNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.ObjectReferenceFluent<io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionStatusFluent.InstallPlanRefNested<N>>{
    public N and();
    public N endInstallPlanRef();
    
  }
  public interface InstallplanNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.operatorhub.v1alpha1.InstallPlanReferenceFluent<io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionStatusFluent.InstallplanNested<N>>{
    public N and();
    public N endInstallplan();
    
  }
  
}

==> openshift-model-operatorhub-5.10.1-sources.jar: io/fabric8/openshift/api/model/operatorhub/v1alpha1/SubscriptionStatusFluent.java <==
package io.fabric8.openshift.api.model.operatorhub.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import io.fabric8.kubernetes.api.model.ObjectReference;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Integer;
import io.fabric8.kubernetes.api.model.ObjectReferenceFluent;
import io.fabric8.kubernetes.api.model.ObjectReferenceBuilder;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public interface SubscriptionStatusFluent<A extends io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionStatusFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public A addToCatalogHealth(java.lang.Integer index,io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionCatalogHealth item);
  public A setToCatalogHealth(java.lang.Integer index,io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionCatalogHealth item);
  public A addToCatalogHealth(io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionCatalogHealth... items);
  public A addAllToCatalogHealth(java.util.Collection<io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionCatalogHealth> items);
  public A removeFromCatalogHealth(io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionCatalogHealth... items);
  public A removeAllFromCatalogHealth(java.util.Collection<io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionCatalogHealth> items);
  public A removeMatchingFromCatalogHealth(java.util.function.Predicate<io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionCatalogHealthBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildCatalogHealth instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionCatalogHealth> getCatalogHealth();
  public java.util.List<io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionCatalogHealth> buildCatalogHealth();
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionCatalogHealth buildCatalogHealth(java.lang.Integer index);
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionCatalogHealth buildFirstCatalogHealth();
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionCatalogHealth buildLastCatalogHealth();
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionCatalogHealth buildMatchingCatalogHealth(java.util.function.Predicate<io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionCatalogHealthBuilder> predicate);
  public java.lang.Boolean hasMatchingCatalogHealth(java.util.function.Predicate<io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionCatalogHealthBuilder> predicate);
  public A withCatalogHealth(java.util.List<io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionCatalogHealth> catalogHealth);
  public A withCatalogHealth(io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionCatalogHealth... catalogHealth);
  public java.lang.Boolean hasCatalogHealth();
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionStatusFluent.CatalogHealthNested<A> addNewCatalogHealth();
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionStatusFluent.CatalogHealthNested<A> addNewCatalogHealthLike(io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionCatalogHealth item);
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionStatusFluent.CatalogHealthNested<A> setNewCatalogHealthLike(java.lang.Integer index,io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionCatalogHealth item);
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionStatusFluent.CatalogHealthNested<A> editCatalogHealth(java.lang.Integer index);
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionStatusFluent.CatalogHealthNested<A> editFirstCatalogHealth();
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionStatusFluent.CatalogHealthNested<A> editLastCatalogHealth();
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionStatusFluent.CatalogHealthNested<A> editMatchingCatalogHealth(java.util.function.Predicate<io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionCatalogHealthBuilder> predicate);
  public A addToConditions(java.lang.Integer index,io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionCondition item);
  public A setToConditions(java.lang.Integer index,io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionCondition item);
  public A addToConditions(io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionCondition... items);
  public A addAllToConditions(java.util.Collection<io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionCondition> items);
  public A removeFromConditions(io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionCondition... items);
  public A removeAllFromConditions(java.util.Collection<io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionCondition> items);
  public A removeMatchingFromConditions(java.util.function.Predicate<io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionConditionBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildConditions instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionCondition> getConditions();
  public java.util.List<io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionCondition> buildConditions();
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionCondition buildCondition(java.lang.Integer index);
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionCondition buildFirstCondition();
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionCondition buildLastCondition();
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionCondition buildMatchingCondition(java.util.function.Predicate<io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionConditionBuilder> predicate);
  public java.lang.Boolean hasMatchingCondition(java.util.function.Predicate<io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionConditionBuilder> predicate);
  public A withConditions(java.util.List<io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionCondition> conditions);
  public A withConditions(io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionCondition... conditions);
  public java.lang.Boolean hasConditions();
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionStatusFluent.ConditionsNested<A> addNewCondition();
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionStatusFluent.ConditionsNested<A> addNewConditionLike(io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionCondition item);
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionStatusFluent.ConditionsNested<A> setNewConditionLike(java.lang.Integer index,io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionCondition item);
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionStatusFluent.ConditionsNested<A> editCondition(java.lang.Integer index);
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionStatusFluent.ConditionsNested<A> editFirstCondition();
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionStatusFluent.ConditionsNested<A> editLastCondition();
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionStatusFluent.ConditionsNested<A> editMatchingCondition(java.util.function.Predicate<io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionConditionBuilder> predicate);
  public java.lang.String getCurrentCSV();
  public A withCurrentCSV(java.lang.String currentCSV);
  public java.lang.Boolean hasCurrentCSV();
  
  /**
   * Method is deprecated. use withCurrentCSV instead.
   */
  @java.lang.Deprecated
  public A withNewCurrentCSV(java.lang.String arg0);
  public java.lang.Integer getInstallPlanGeneration();
  public A withInstallPlanGeneration(java.lang.Integer installPlanGeneration);
  public java.lang.Boolean hasInstallPlanGeneration();
  
  /**
   * This method has been deprecated, please use method buildInstallPlanRef instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.ObjectReference getInstallPlanRef();
  public io.fabric8.kubernetes.api.model.ObjectReference buildInstallPlanRef();
  public A withInstallPlanRef(io.fabric8.kubernetes.api.model.ObjectReference installPlanRef);
  public java.lang.Boolean hasInstallPlanRef();
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionStatusFluent.InstallPlanRefNested<A> withNewInstallPlanRef();
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionStatusFluent.InstallPlanRefNested<A> withNewInstallPlanRefLike(io.fabric8.kubernetes.api.model.ObjectReference item);
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionStatusFluent.InstallPlanRefNested<A> editInstallPlanRef();
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionStatusFluent.InstallPlanRefNested<A> editOrNewInstallPlanRef();
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionStatusFluent.InstallPlanRefNested<A> editOrNewInstallPlanRefLike(io.fabric8.kubernetes.api.model.ObjectReference item);
  public java.lang.String getInstalledCSV();
  public A withInstalledCSV(java.lang.String installedCSV);
  public java.lang.Boolean hasInstalledCSV();
  
  /**
   * Method is deprecated. use withInstalledCSV instead.
   */
  @java.lang.Deprecated
  public A withNewInstalledCSV(java.lang.String arg0);
  
  /**
   * This method has been deprecated, please use method buildInstallplan instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.InstallPlanReference getInstallplan();
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.InstallPlanReference buildInstallplan();
  public A withInstallplan(io.fabric8.openshift.api.model.operatorhub.v1alpha1.InstallPlanReference installplan);
  public java.lang.Boolean hasInstallplan();
  public A withNewInstallplan(java.lang.String apiVersion,java.lang.String kind,java.lang.String name,java.lang.String uuid);
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionStatusFluent.InstallplanNested<A> withNewInstallplan();
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionStatusFluent.InstallplanNested<A> withNewInstallplanLike(io.fabric8.openshift.api.model.operatorhub.v1alpha1.InstallPlanReference item);
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionStatusFluent.InstallplanNested<A> editInstallplan();
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionStatusFluent.InstallplanNested<A> editOrNewInstallplan();
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionStatusFluent.InstallplanNested<A> editOrNewInstallplanLike(io.fabric8.openshift.api.model.operatorhub.v1alpha1.InstallPlanReference item);
  public java.lang.String getLastUpdated();
  public A withLastUpdated(java.lang.String lastUpdated);
  public java.lang.Boolean hasLastUpdated();
  
  /**
   * Method is deprecated. use withLastUpdated instead.
   */
  @java.lang.Deprecated
  public A withNewLastUpdated(java.lang.String arg0);
  public java.lang.String getReason();
  public A withReason(java.lang.String reason);
  public java.lang.Boolean hasReason();
  
  /**
   * Method is deprecated. use withReason instead.
   */
  @java.lang.Deprecated
  public A withNewReason(java.lang.String arg0);
  public java.lang.String getState();
  public A withState(java.lang.String state);
  public java.lang.Boolean hasState();
  
  /**
   * Method is deprecated. use withState instead.
   */
  @java.lang.Deprecated
  public A withNewState(java.lang.String arg0);
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value);
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public A removeFromAdditionalProperties(java.lang.String key);
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties);
  public java.lang.Boolean hasAdditionalProperties();
  public interface CatalogHealthNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionCatalogHealthFluent<io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionStatusFluent.CatalogHealthNested<N>>{
    public N and();
    public N endCatalogHealth();
    
  }
  public interface ConditionsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionConditionFluent<io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionStatusFluent.ConditionsNested<N>>{
    public N and();
    public N endCondition();
    
  }
  public interface InstallPlanRefNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.ObjectReferenceFluent<io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionStatusFluent.InstallPlanRefNested<N>>{
    public N and();
    public N endInstallPlanRef();
    
  }
  public interface InstallplanNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.operatorhub.v1alpha1.InstallPlanReferenceFluent<io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionStatusFluent.InstallplanNested<N>>{
    public N and();
    public N endInstallplan();
    
  }
  
}
